package WordListBundle::EN::ByClass::Noun;

use strict;

our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
our $DATE = '2025-01-13'; # DATE
our $DIST = 'WordListBundle-EN-ByClass-Noun'; # DIST
our $VERSION = '0.005'; # VERSION

1;
# ABSTRACT: Collection of English nouns

__END__

=pod

=encoding UTF-8

=head1 NAME

WordListBundle::EN::ByClass::Noun - Collection of English nouns

=head1 VERSION

This document describes version 0.005 of WordListBundle::EN::ByClass::Noun (from Perl distribution WordListBundle-EN-ByClass-Noun), released on 2025-01-13.

=head1 DESCRIPTION

This distribution contains the following wordlist modules:

=over

=item * L<WordList::EN::ByClass::Noun::TalkEnglish>

=back

=head1 HOMEPAGE

Please visit the project's homepage at L<https://metacpan.org/release/WordListBundle-EN-ByClass-Noun>.

=head1 SOURCE

Source repository is at L<https://github.com/perlancar/perl-WordListBundle-EN-ByClass-Noun>.

=head1 SEE ALSO

L<TableDataBundle::Lingua::Word::EN::ByClass::Noun>

L<WordListBundle::EN::ByClass::Adjective>,
L<WordListBundle::EN::ByClass::Adverb>

L<WordList>

The wordlists can be used for games, e.g. L<Games::Hangman>, L<Games::TabNoun>.

=head1 AUTHOR

perlancar <perlancar@cpan.org>

=head1 CONTRIBUTING


To contribute, you can send patches by email/via RT, or send pull requests on
GitHub.

Most of the time, you don't need to build the distribution yourself. You can
simply modify the code, then test via:

 % prove -l

If you want to build the distribution (e.g. to try to install it locally on your
system), you can install L<Dist::Zilla>,
L<Dist::Zilla::PluginBundle::Author::PERLANCAR>,
L<Pod::Weaver::PluginBundle::Author::PERLANCAR>, and sometimes one or two other
Dist::Zilla- and/or Pod::Weaver plugins. Any additional steps required beyond
that are considered a bug and can be reported to me.

=head1 COPYRIGHT AND LICENSE

This software is copyright (c) 2025 by perlancar <perlancar@cpan.org>.

This is free software; you can redistribute it and/or modify it under
the same terms as the Perl 5 programming language system itself.

=head1 BUGS

Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=WordListBundle-EN-ByClass-Noun>

When submitting a bug or request, please include a test-file or a
patch to an existing test-file that illustrates the bug or desired
feature.

=cut
